@@ -21,7 +21,7 @@ MA 02110-1301 USA
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.58 2006/06/02 14:24:38 evertonm Exp $
+  $Id: main.c,v 1.59 2006/06/07 13:42:38 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -84,6 +84,7 @@ static void usage(FILE *out, const char *prog_name)
           "common (client/server) options:\n"
           "  -h             help\n"
           "  -v             show program version\n"
+	  "  -V             verbose error messages\n"
           "  -b addr-list   bind to specific addresses (defaults to any)\n"
           "  -p port        server port number (defaults to %s)\n"
           "  -m mode        path MTU discovery mode (defaults to %d)\n"
@@ -727,6 +728,11 @@ int main(int argc, const char *argv[])
       exit(0);
     }
 
+    if (!strcmp(arg, "-V")) {
+      nepim_global.verbose_stderr = stderr;
+      continue;
+    }
+
     if (!strcmp(arg, "-w")) {
       ++i;
       if (i >= argc) {
